API Reference
=============

Core Drawing Module
-------------------

.. automodule:: kicad_draw.PCBmodule
   :members:

Parameter Models
----------------

.. automodule:: kicad_draw.models
   :members:

Visualization
-------------

.. automodule:: kicad_draw.visualizer
   :members:

Layer Management
----------------

.. automodule:: kicad_draw.layers
   :members:

Geometry Classes
----------------

.. automodule:: kicad_draw.geometry
   :members:

Formatting
----------

.. automodule:: kicad_draw.formatter
   :members:

Configuration
-------------

.. automodule:: kicad_draw.config
   :members: